"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var testUtils_1 = require("./testUtils");
describe('parser', function () {
    var children = { type: 'ReactNode', required: false, description: '', };
    it('should parse simple react class component', function () {
        testUtils_1.check('Column', {
            Column: {
                children: children,
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component as default export', function () {
        testUtils_1.check('ColumnWithDefaultExport', {
            Column: {
                children: children,
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component as default export only', function () {
        testUtils_1.check('ColumnWithDefaultExportOnly', {
            ColumnWithDefaultExportOnly: {
                children: children,
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component as default anonymous export', function () {
        testUtils_1.check('ColumnWithDefaultAnonymousExportOnly', {
            ColumnWithDefaultAnonymousExportOnly: {
                children: children,
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component with state', function () {
        testUtils_1.check('AppMenu', {
            AppMenu: {
                children: children,
                menu: { type: 'any' },
            }
        });
    });
    it('should parse simple react class component with picked properties', function () {
        // we are not able to get correct descriptions for prop1,prop2
        testUtils_1.check('ColumnWithPick', {
            Column: {
                children: children,
                prop1: { type: 'string', required: false, description: '' },
                prop2: { type: 'number', description: '' },
                propx: { type: 'number' },
            }
        });
    });
    it('should parse HOCs', function () {
        testUtils_1.check('ColumnHigherOrderComponent', {
            ColumnHigherOrderComponent1: {
                children: children,
                prop1: { type: 'string' },
            },
            ColumnHigherOrderComponent2: {
                children: children,
                prop1: { type: 'string' },
            },
            RowHigherOrderComponent1: {
                prop1: { type: 'string' },
            },
            RowHigherOrderComponent2: {
                prop1: { type: 'string' },
            },
            ColumnExternalHigherOrderComponent: {
                children: children,
                prop1: { type: 'string' },
            },
            RowExternalHigherOrderComponent: {
                prop1: { type: 'string' },
            }
        });
    });
    it('should parse component with inherited properties HtmlAttributes<any>', function () {
        testUtils_1.check('ColumnWithHtmlAttributes', {
            Column: {
                children: children,
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                // HtmlAttributes
                defaultChecked: {
                    type: 'boolean',
                    required: false,
                    description: ''
                }
                // ...
            }
        }, false);
    });
    it('should parse component without exported props interface', function () {
        testUtils_1.check('ColumnWithoutExportedProps', {
            Column: {
                children: children,
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            }
        });
    });
    it('should parse functional component exported as const', function () {
        testUtils_1.check('ConstExport', {
            Row: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            },
            // TODO: this wasn't there before, i would guess that that's correct
            test: {}
        }, false);
    });
    it('should parse react component with properties defined in external file', function () {
        testUtils_1.check('ExternalPropsComponent', {
            ExternalPropsComponent: {
                children: children,
                prop1: { type: 'string' },
            }
        });
    });
    it('should parse react component with properties extended from an external .tsx file', function () {
        testUtils_1.check('ExtendsExternalPropsComponent', {
            ExtendsExternalPropsComponent: {
                children: children,
                prop1: { type: 'number', required: false, description: 'prop1' },
                prop2: { type: 'string', required: false, description: 'prop2' },
            }
        });
    });
    it('should parse react component with properties defined as type', function () {
        testUtils_1.check('FlippableImage', {
            FlippableImage: {
                children: children,
                isFlippedX: { type: 'boolean', required: false },
                isFlippedY: { type: 'boolean', required: false },
            }
        }, false);
    });
    it('should parse react component with const definitions', function () {
        testUtils_1.check('InlineConst', {
            MyComponent: {
                children: children,
                foo: { type: 'any' },
            }
        });
    });
    it('should parse react component with default props', function () {
        testUtils_1.check('ComponentWithDefaultProps', {
            ComponentWithDefaultProps: {
                children: children,
                sampleDefaultFromJSDoc: { type: '"hello" | "goodbye"', required: true, defaultValue: "hello", description: 'sample with default value' },
                sampleTrue: { type: "boolean", required: false, defaultValue: "true" },
                sampleFalse: { type: "boolean", required: false, defaultValue: "false" },
                sampleString: { type: "string", required: false, defaultValue: "hello" },
                sampleObject: { type: "{ [key: string]: any; }", required: false, defaultValue: "{ a: '1', b: 2, c: true, d: false, e: undefined, f: null, g: { a: '1' } }" },
                sampleNull: { type: "null", required: false, defaultValue: "null" },
                sampleUndefined: { type: "any", required: false, defaultValue: "undefined" },
            }
        });
    });
    it('should parse react PureComponent', function () {
        testUtils_1.check('PureRow', {
            Row: {
                children: children,
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            }
        });
    });
    it('should parse react PureComponent - regression test', function () {
        testUtils_1.check('Regression_v0_0_12', {
            Zoomable: {
                children: children,
                originX: { type: 'number' },
                originY: { type: 'number' },
                scaleFactor: { type: 'number' }
            }
        }, false);
    });
    it('should parse react functional component', function () {
        testUtils_1.check('Row', {
            Row: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            }
        });
    });
    it('should parse react stateless component', function () {
        testUtils_1.check('Stateless', {
            Stateless: {
                children: children,
                myProp: { type: 'string' },
            }
        });
    });
    it('should parse react stateless component with default props', function () {
        testUtils_1.check('StatelessWithDefaultProps', {
            StatelessWithDefaultProps: {
                children: children,
                sampleJSDoc: { type: "string", required: false, defaultValue: "test" },
                sampleProp: { type: "string", required: false, defaultValue: "hello" },
            }
        });
    });
});
//# sourceMappingURL=parser.js.map